import { Button } from "@/components/ui/button";
import { Label } from "@/components/ui/label";
import { Input } from "@/components/ui/input";
import { cn } from "@/lib/utils";
import { Card, CardContent, CardFooter } from "@/components/ui/card";
import { useRef, useState } from "react";
import { Check, XCircle } from "lucide-react";
import { useDebounce, useOnClickOutside } from "usehooks-ts";

export function AddTag({ className }: React.HTMLAttributes<HTMLDivElement>) {
  const colors = [
    "bg-blue-300",
    "bg-red-300",
    "bg-orange-300",
    "bg-yellow-300",
    "bg-lime-300",
    "bg-green-300",
    "bg-sky-300",
    "bg-purple-300",
    "bg-pink-300",
    "bg-gray-300",
  ];

  const [selectedColor, setSelectedColor] = useState(colors[0]);
  const [inputValue, setInputValue] = useState("");
  const ref = useRef(null);

  const clear = () => {
    setSelectedColor(colors[0]);
    setInputValue("");
  };

  useOnClickOutside(ref, clear);

  const handleSubmit = () => {
    console.log({ inputValue, selectedColor });
  };

  return (
    <Card className={cn("w-[272px] h-fit", className)} ref={ref}>
      <CardContent className="p-4 space-y-4">
        <div className="space-y-2 relative">
          <Label>标签名称</Label>
          <Input
            value={inputValue}
            className="h-8 outline-none pr-8"
            onChange={(e) => setInputValue(e.target.value)}
          />
          <XCircle
            className={cn(
              "w-4 h-4 absolute bottom-2 right-2 text-primary/60 hover:text-primary/80 cursor-pointer",
              !inputValue && "hidden"
            )}
            onClick={() => setInputValue("")}
          />
        </div>
        <div className="space-y-2">
          <Label>颜色</Label>
          <div className="flex justify-between items-center">
            {colors.map((color) => (
              <div
                key={color}
                onClick={() => setSelectedColor(color)}
                className={cn(
                  color,
                  " w-[18px] h-[18px]",
                  "rounded-[2px] flex justify-center items-center",
                  "cursor-pointer"
                )}
              >
                {selectedColor === color && (
                  <Check className="w-[14px] h-[14px]" />
                )}
              </div>
            ))}
          </div>
        </div>
        <CardFooter className="flex justify-end gap-2 p-0 [&_button]:w-18 [&_button]:p-4 [&_button]:h-8 [&_button]:w-18">
          <Button variant="outline" onClick={clear}>
            取消
          </Button>
          <Button disabled={!inputValue} onClick={handleSubmit}>
            确认
          </Button>
        </CardFooter>
      </CardContent>
    </Card>
  );
}
