"use client";

import {
  Command,
  CommandGroup,
  CommandItem,
  CommandList,
  CommandSeparator,
} from "@/components/ui/command";
import { cn } from "@/lib/utils";
import { Check, Plus } from "lucide-react";
import React, { useState } from "react";

interface ITagListProps extends React.HTMLAttributes<HTMLDivElement> {
  list: TagItem[];
}

export default function TagList({ list, className }: ITagListProps) {
  const [selectedValue, setSelectedValue] = useState("0");
  return (
    <Command className={cn("rounded-lg border shadow-md h-fit p-2", className)}>
      <CommandList>
        <CommandGroup>
          {list.map((tag) => (
            <CommandItem
              value={tag.id + ""}
              key={tag.id}
              className="flex justify-between items-center cursor-pointer"
              onSelect={(v) => setSelectedValue(v + "")}
            >
              <div className="flex justify-start items-center">
                <div className={cn("mr-2 h-2 w-2 rounded-[2px]", tag.color)} />
                <span>{tag.name}</span>
              </div>
              {selectedValue === tag.id + "" && (
                <Check className="ml-2 h-4 w-4 text-primary" />
              )}
            </CommandItem>
          ))}
        </CommandGroup>
        <CommandSeparator />
        <CommandGroup>
          <CommandItem className=" cursor-pointer">
            <Plus className="w-4 h-4 mr-2" />
            <span>新建标签</span>
          </CommandItem>
        </CommandGroup>
      </CommandList>
    </Command>
  );
}
